##  Linking an IT Component Fact Sheet During Fact Sheet Creation
You can link an IT component to a catalog item from the fact sheet creation overlay. Follow these steps:
  1. Enter the name of the IT component in the fact sheet creation overlay. As you type the name, recommendations from the reference catalog appear below the input field.
  2. Choose the appropriate catalog item, then click Create & Link.


![Linking IT Component Fact Sheet During Fact Sheet Creation](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274c22317a441014adf2db35f71c9b36_LowRes.gif)
Linking IT Component Fact Sheet During Fact Sheet Creation
